import { cx, css } from '@emotion/css';
import React__default from 'react';
import { LoadingState } from '@grafana/data';
import { selectors } from '@grafana/e2e-selectors';
import { useTheme2, useStyles2 } from '../../themes/ThemeContext.js';
import 'memoize-one';
import '@emotion/react';
import 'tinycolor2';
import { Icon } from '../Icon/Icon.js';
import { LoadingBar } from '../LoadingBar/LoadingBar.js';
import { Tooltip } from '../Tooltip/Tooltip.js';
import { HoverWidget } from './HoverWidget.js';
import { PanelDescription } from './PanelDescription.js';
import { PanelMenu } from './PanelMenu.js';
import { PanelStatus } from './PanelStatus.js';
import { TitleItem } from './TitleItem.js';

function PanelChrome({
  width,
  height,
  children,
  padding = "md",
  title = "",
  description = "",
  displayMode = "default",
  titleItems,
  menu,
  dragClass,
  dragClassCancel,
  hoverHeader = false,
  hoverHeaderOffset,
  loadingState,
  statusMessage,
  statusMessageOnClick,
  leftItems
}) {
  var _a;
  const theme = useTheme2();
  const styles = useStyles2(getStyles);
  const hasHeader = hoverHeader === false && (title.length > 0 || titleItems !== void 0 || description !== "" || loadingState === LoadingState.Streaming || ((_a = leftItems == null ? void 0 : leftItems.length) != null ? _a : 0) > 0);
  const headerHeight = getHeaderHeight(theme, hasHeader);
  const { contentStyle, innerWidth, innerHeight } = getContentStyle(padding, theme, width, headerHeight, height);
  const headerStyles = {
    height: headerHeight,
    cursor: dragClass ? "move" : "auto"
  };
  const containerStyles = { width, height };
  if (displayMode === "transparent") {
    containerStyles.backgroundColor = "transparent";
    containerStyles.border = "none";
  }
  const ariaLabel = title ? selectors.components.Panels.Panel.containerByTitle(title) : "Panel";
  const headerContent = /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, title && /* @__PURE__ */ React__default.createElement("h6", { title, className: styles.title }, title), /* @__PURE__ */ React__default.createElement(PanelDescription, { description, className: dragClassCancel }), titleItems !== void 0 && /* @__PURE__ */ React__default.createElement("div", { className: cx(styles.titleItems, dragClassCancel), "data-testid": "title-items-container" }, titleItems), loadingState === LoadingState.Streaming && /* @__PURE__ */ React__default.createElement(Tooltip, { content: "Streaming" }, /* @__PURE__ */ React__default.createElement(TitleItem, { className: dragClassCancel, "data-testid": "panel-streaming" }, /* @__PURE__ */ React__default.createElement(Icon, { name: "circle-mono", size: "md", className: styles.streaming }))));
  return /* @__PURE__ */ React__default.createElement(
    "div",
    {
      className: cx(styles.container, { [styles.regularHeader]: hasHeader }),
      style: containerStyles,
      "aria-label": ariaLabel
    },
    /* @__PURE__ */ React__default.createElement("div", { className: styles.loadingBarContainer }, loadingState === LoadingState.Loading ? /* @__PURE__ */ React__default.createElement(LoadingBar, { width, ariaLabel: "Panel loading bar" }) : null),
    (hoverHeader || !hasHeader) && menu && /* @__PURE__ */ React__default.createElement(HoverWidget, { menu, title, offset: hoverHeaderOffset, dragClass }, headerContent),
    hasHeader && /* @__PURE__ */ React__default.createElement("div", { className: cx(styles.headerContainer, dragClass), style: headerStyles, "data-testid": "header-container" }, headerContent, /* @__PURE__ */ React__default.createElement("div", { className: styles.rightAligned }, menu && /* @__PURE__ */ React__default.createElement(
      PanelMenu,
      {
        menu,
        title,
        menuButtonClass: cx(styles.menuItem, dragClassCancel, "show-on-hover")
      }
    ), leftItems && /* @__PURE__ */ React__default.createElement("div", { className: styles.leftItems }, itemsRenderer(leftItems, (item) => item)))),
    statusMessage && /* @__PURE__ */ React__default.createElement(
      PanelStatus,
      {
        className: cx(styles.errorContainer, dragClassCancel),
        message: statusMessage,
        onClick: statusMessageOnClick,
        ariaLabel: "Panel status"
      }
    ),
    /* @__PURE__ */ React__default.createElement("div", { className: styles.content, style: contentStyle }, children(innerWidth, innerHeight))
  );
}
const itemsRenderer = (items, renderer) => {
  const toRender = React__default.Children.toArray(items).filter(Boolean);
  return toRender.length > 0 ? renderer(toRender) : null;
};
const getHeaderHeight = (theme, hasHeader) => {
  if (hasHeader) {
    return theme.spacing.gridSize * theme.components.panel.headerHeight;
  }
  return 0;
};
const getContentStyle = (padding, theme, width, headerHeight, height) => {
  const chromePadding = (padding === "md" ? theme.components.panel.padding : 0) * theme.spacing.gridSize;
  const panelPadding = chromePadding * 2;
  const panelBorder = 1 * 2;
  const innerWidth = width - panelPadding - panelBorder;
  const innerHeight = height - headerHeight - panelPadding - panelBorder;
  const contentStyle = {
    padding: chromePadding
  };
  return { contentStyle, innerWidth, innerHeight };
};
const getStyles = (theme) => {
  const { background, borderColor, padding } = theme.components.panel;
  return {
    container: css({
      label: "panel-container",
      backgroundColor: background,
      border: `1px solid ${borderColor}`,
      position: "relative",
      borderRadius: "3px",
      height: "100%",
      display: "flex",
      flexDirection: "column",
      flex: "1 1 0",
      ".show-on-hover": {
        visibility: "hidden",
        opacity: "0"
      },
      "&:focus-visible, &:hover": {
        // only show menu icon on hover or focused panel
        ".show-on-hover": {
          visibility: "visible",
          opacity: "1"
        }
      },
      "&:focus-visible": {
        outline: `1px solid ${theme.colors.action.focus}`
      }
    }),
    regularHeader: css({
      "&:focus-within": {
        ".show-on-hover": {
          visibility: "visible",
          opacity: "1"
        }
      }
    }),
    loadingBarContainer: css({
      label: "panel-loading-bar-container",
      position: "absolute",
      top: 0,
      width: "100%",
      overflow: "hidden"
    }),
    content: css({
      label: "panel-content",
      flexGrow: 1,
      contain: "strict"
    }),
    headerContainer: css({
      label: "panel-header",
      display: "flex",
      alignItems: "center",
      padding: theme.spacing(0, 0, 0, padding)
    }),
    streaming: css({
      label: "panel-streaming",
      marginRight: 0,
      color: theme.colors.success.text,
      "&:hover": {
        color: theme.colors.success.text
      }
    }),
    title: css({
      label: "panel-title",
      marginBottom: 0,
      // override default h6 margin-bottom
      paddingRight: theme.spacing(1),
      textOverflow: "ellipsis",
      overflow: "hidden",
      whiteSpace: "nowrap",
      maxWidth: theme.spacing(50),
      fontSize: theme.typography.h6.fontSize,
      fontWeight: theme.typography.h6.fontWeight
    }),
    items: css({
      display: "flex"
    }),
    item: css({
      display: "flex",
      justifyContent: "center",
      alignItems: "center"
    }),
    menuItem: css({
      label: "panel-menu",
      visibility: "hidden",
      border: "none"
    }),
    errorContainer: css({
      label: "error-container",
      position: "absolute",
      left: "50%",
      transform: "translateX(-50%)",
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      zIndex: theme.zIndex.tooltip
    }),
    leftItems: css({
      display: "flex",
      paddingRight: theme.spacing(padding)
    }),
    rightAligned: css({
      label: "right-aligned-container",
      marginLeft: "auto",
      display: "flex",
      alignItems: "center"
    }),
    titleItems: css({
      display: "flex",
      height: "100%"
    })
  };
};

export { PanelChrome };
//# sourceMappingURL=PanelChrome.js.map
